import logging
FORMAT = "[%(asctime)s%(filename)s:%(lineno)s - %(funcName)s() ] %(message)s"
logging.basicConfig(filename='output.log',format=FORMAT)
logger = logging.getLogger('root')
logger.setLevel(logging.DEBUG)

import dataset
from book import Book

class BookDao:
    def __init__(self):
        self.connectString = 'sqlite:///books.db'
        self.db = dataset.connect(self.connectString)
        self.table = self.db['books']

    def rowToBook(self,row):
        book = Book(row['title'], row['author'], row['isbn'], row['votes'])
        return book

    def bookToRow(self,book):
        row = dict(title=book.title, author=book.author, isbn=book.isbn, votes=book.votes)
        return row

    def selectByISBN(self,isbn):
        row = self.table.find_one(isbn=isbn)

        result = None
        if (row is None):
            logger.error('Failed to find book with ' + isbn)
        else:
            result = self.rowToBook(row)
            
        return result

    def selectAll(self):
        rows   = self.table.all()
        
        result = []
        for row in rows:
            result.append(self.rowToBook(row))

        return result
        
    def insert(self,book):
        self.table.insert(self.bookToRow(book))
        self.db.commit()

    def update(self,book):
        self.table.update(self.bookToRow(book),['isbn'])
        self.db.commit()

    def delete(self,book):
        self.table.delete(isbn=book.isbn)
        self.db.commit()

    def populate(self):
        self.table.insert(self.bookToRow(Book('The Talisman','Stephen King','1111',0)))
        self.table.insert(self.bookToRow(Book('The Stand','Stephen King','2222',0)))
        self.table.insert(self.bookToRow(Book('The Shining','Stephen King','3333',0)))
        self.table.insert(self.bookToRow(Book('The Dark Tower','Stephen King','4444',0)))
        self.db.commit()
