from jsonpickle import encode
from flask import Flask
from flask import abort, redirect, url_for
from flask import request
from flask import render_template
from flask import session
from book import Book
import logging
from bookdao import BookDao
from book import Book
from userdao import UserDao
from user import User

app = Flask(__name__)

@app.route('/')
def index():
    return redirect(url_for('login'))

@app.route('/login', methods=['POST', 'GET'])
def login():
    error = None

    if ('userid' in request.form):
        if isValid(request.form['userid'],request.form['password']):
            return survey()
        else:
            error = 'Invalid userid/password'

    # the code below is executed if userid not found in form
    return render_template('login.html', **locals())


def isValid(userid, password):
    dao = UserDao()
    user = dao.selectByUserid(userid)
    
    if (user is not None) and (userid == user.userid) and (password == user.password):
        session['user']=encode(user) # use an encoder to convert user to a JSON object for session
        return True
    else:
        return False

@app.route('/survey', methods=['POST', 'GET'])
def survey():
    error = None

    # Get the books from data store
    dao = BookDao()
    books = dao.selectAll()
    
    #### NOTE!  The form must use method=POST or stuff won't show up in request.form
    # How to dump data in POST:
    # for key, value in request.form.items() :
    #    print (key, value)

    # We have a vote, save book ISBN in session
    if ('isbn' in request.form):
        session['isbn']=request.form['isbn']
        return results()

    # We don't have a vote, display the survey form
    else:
        return render_template('survey.html', **locals())

@app.route('/results', methods=['POST', 'GET'])
def results():
    error = None

    # Get the books from data store
    dao = BookDao()
    
    # Check for error, we should have an ISBN
    if ('isbn' not in session):
        error = "BookVote:results() Error ISBN was not found in POST data"
    # No error
    else:
        isbn = session['isbn']
        session['isbn']=None

        book = dao.selectByISBN(isbn)
        book.votes = book.votes + 1
        dao.update(book)

    books = dao.selectAll()
    return render_template('results.html', **locals())

if __name__ == "__main__":
    app.secret_key = 'A0Zr98j/3yX R~XHH!jmN]LWX/,?RT'
    app.run(host='0.0.0.0', port=8000, threaded=True, debug=True)
